@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-01-19'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -100,26 +100,39 @@ sub __gen_table {
         # 0->2, 1->0, ... (map column position from unordered to ordered)
         my @map0 = sort {
             my $idx_a = firstidx(sub {$_ eq $a->[1]},
-                                                  @$column_orders) // 9999;
+                                 @$column_orders) // 9999;
             my $idx_b = firstidx(sub {$_ eq $b->[1]},
-                                                  @$column_orders) // 9999;
+                                 @$column_orders) // 9999;
             $idx_a <=> $idx_b || $a->[1] cmp $b->[1];
-        } map {[$_, $columns[$_]]} 0..@columns-1;
+        } map {[$_, $columns[$_]]} 0..$#columns;
         #use DD; dd \@map0;
         my @map;
-        for (0..@map0-1) {
+        for (0..$#map0) {
             $map[$_] = $map0[$_][0];
         }
         #use DD; dd \@map;
         my $newdata = [];
         for my $row (@$data) {
             my @newrow;
-            for (0..@map-1) { $newrow[$_] = $row->[$map[$_]] }
+            for (0..$#map) { $newrow[$_] = $row->[$map[$_]] }
             push @$newdata, \@newrow;
         }
         $data = $newdata;
     }
 
+    # add field units as label (" (UNIT)")
+    {
+        last unless $header_row && @$data;
+        my $tff = $resmeta->{'table.fields'} or last;
+        my $tfu = $resmeta->{'table.field_units'} or last;
+        for my $i (0..$#{$data->[0]}) {
+            my $field_idx = firstidx { $_ eq $data->[0][$i] } @$tff;
+            next unless $field_idx;
+            next unless defined $tfu->[$field_idx];
+            $data->[0][$i] .= " ($tfu->[$field_idx])";
+        }
+    }
+
     if ($format eq 'text-pretty') {
         require Text::Table::Tiny;
         Text::Table::Tiny::table(rows=>$data, header_row=>$header_row) . "\n";
@@ -242,7 +255,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-13.
+This document describes version 0.12 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-19.
 
 =head1 SYNOPSIS
 
@@ -262,12 +275,6 @@ Set the default of C<table_column_orders> in C<format_options> in result
 metadata, similar to what's implemented in L<Perinci::Result::Format> and
 L<Data::Format::Pretty::Console>.
 
-=head1 SEE ALSO
-
-L<Perinci::Result::Format>, a more heavyweight version of this module.
-
-L<Perinci::CmdLine::Lite> uses this module to format enveloped result.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Result-Format-Lite>.
@@ -284,6 +291,12 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::Result::Format>, a more heavyweight version of this module.
+
+L<Perinci::CmdLine::Lite> uses this module to format enveloped result.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
